/*
 * vistaFace
 *
 * $Id: vistaFace.js 402 2008-08-18 20:06:28Z tomoyo $
 *
 * Modified by Butz Yung / Anime Theme for use with "System Animator" gadget
 * Homepage: http://www.animetheme.com/
 * Email: webmaster@animetheme.com
 *
 * License: MIT License
 */

var DEFAULT_FACEDEF_DIR = System.Gadget.path + "\\images\\MacFace01.mcface";
var EV_width = 128
var EV_height = 128

function _VistaFace() {
    this.mainFrame = null;
    this.faceDefDir = null;
    this.currentFace = null;
    this.partsBackground = null;

    // cache settings
    this._cache = {
        imgObjs: [],
        backgroundPartFilename : '',
        cpuUsageIndex : -1,
        memUsageIndex : -1,
        marker1 : -1,
        marker2 : -1
    };

    this.settings = {};
};

_VistaFace.prototype = {
    main : function () {
        try {
            this.initialize();
            this.setupFaceDef();
        } catch (e) {}
    }

    , initialize : function () {
//        this.mainFrame = document.getElementById("gadgetMainFrame");
        this.partsBackground = document.getElementById("BG");

        this.settings.faceDefDir = Settings.f_path;
    }

    , setupFaceDef : function () {
        // load face
        this.currentFace = this.loadFaceDef(this.settings.faceDefDir);
        if (this.currentFace == null) {
            // default
            this.currentFace = this.loadFaceDef(DEFAULT_FACEDEF_DIR);
        }
    }

    , loadFaceDef : function (name) {
        this.faceDefDir = name;
        this._cache.backgroundPartFilename = '';
        this._cache.imgObjs = [];
        return this.loadFaceDefPlist(name);
    }
    
    , loadFaceDefPlist : function (name) {
        var faceDefPlist = name + "\\faceDef.plist";
        var plistXMLDoc = new ActiveXObject("Msxml2.DOMDocument.3.0");
        try {
            plistXMLDoc.async = false;
            plistXMLDoc.resolveExternals = false;
            plistXMLDoc.validateOnParse = false;
            plistXMLDoc.load(faceDefPlist);

            return PlistXMLParser.fromXMLDocument(plistXMLDoc);
        } catch (e) {
            return null;
        }
    }
    
    , addPart : function (part) {
         var imgObj = this._cache.imgObjs[part.filename];
         if (!imgObj) {
             imgObj = this.partsBackground.addImageObject(this.faceDefDir + "\\" + part.filename, part['pos x'], 0);
             imgObj.top = 128 - part['pos y'] - imgObj.height;
             this._cache.imgObjs[part.filename] = imgObj;
         }
         imgObj.opacity = 100;
    }
    
    , switchPattern : function (cpuUsageIndex, memUsageIndex, marker1, marker2) {
        // compare cache
        if (this._cache.cpuUsageIndex == cpuUsageIndex &&
            this._cache.memUsageIndex == memUsageIndex &&
            this._cache.marker1 == marker1 &&
            this._cache.marker2 == marker2)
        {
            return;
        }

        // save cache
        this._cache.cpuUsageIndex = cpuUsageIndex;
        this._cache.memUsageIndex = memUsageIndex;
        this._cache.marker1 = marker1;
        this._cache.marker2 = marker2;

        // hide all parts
        for (var i in this._cache.imgObjs) {
            this._cache.imgObjs[i].opacity = 0;
        }

        for (var i = 0, n = this.currentFace.pattern[memUsageIndex][cpuUsageIndex].length; i < n; i++) {
            var partNum = this.currentFace.pattern[memUsageIndex][cpuUsageIndex][i];
            var part = this.currentFace.parts[partNum];
            if (i != 0) {
                this.addPart(part);
            } else {
              if (this._cache.backgroundPartFilename != part.filename) {
                this._cache.backgroundPartFilename = part.filename;
                this._cache.imgObjs = [];
                this.partsBackground.removeObjects();
              }
              this.addPart(part);
            }
        }
        if (marker1) {
            var part = this.currentFace.parts[this.currentFace.markers[0]];
            this.addPart(part);
        }
        if (marker2) {
            var part = this.currentFace.parts[this.currentFace.markers[1]];
            this.addPart(part);
        }
    }
};
var VistaFace = new _VistaFace();
